@@ -1,4 +1,4 @@
-# Copyright 2007-2014 VPAC
+# Copyright 2013-2017, Brian May
 #
 # This file is part of python-alogger.
 #
@@ -14,20 +14,27 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 import importlib
-import warnings
 import logging
+import warnings
+
+
 logger = logging.getLogger(__name__)
 
+
+__author__ = """Brian May"""
+__email__ = 'brian@linuxpenguins.xyz'
+__version__ = '2.2.11'
+
 _plugins = {}
 
 
 def register_plugin(module_name, log_type):
     _plugins[log_type] = module_name
 
+
 register_plugin("alogger.parsers.torque.Parser", "TORQUE")
 register_plugin("alogger.parsers.torque.PbsParser", "PBS")
 register_plugin("alogger.parsers.sge.Parser", "SGE")
