@@ -1,4 +1,4 @@
-# Copyright 2007-2014 VPAC
+# Copyright 2013-2017, Brian May
 #
 # This file is part of python-alogger.
 #
@@ -14,10 +14,10 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with python-alogger  If not, see <http://www.gnu.org/licenses/>.
-from __future__ import absolute_import
-from __future__ import unicode_literals
+from __future__ import absolute_import, unicode_literals
 
 import unittest
+
 from .base import Base
 
 
